@@ -28,7 +28,8 @@
 import gtk 
 import gobject
 import hildon
-import pygame
+import sys
+from pygame import mixer
 from time import strftime
 from datetime import datetime, timedelta
 
@@ -37,7 +38,7 @@ from portrait import FremantleRotation
 STOPWATCH = 1
 COUNTDOWN = 2
 
-class NS(hildon.Program):
+class StopwatchApp(hildon.Program):
     def __init__(self):
         hildon.Program.__init__(self)
         
@@ -74,8 +75,8 @@ class NS(hildon.Program):
         self.clear_time()
         
         # load beep
-        pygame.mixer.init()
-        self.sound = pygame.mixer.Sound("/usr/share/sounds/ui-default_beep.wav")
+        mixer.init()
+        self.sound = mixer.Sound("/usr/share/sounds/ui-default_beep.wav")
         
         self.drawUI()
         menu = self.create_menu(None)
@@ -487,5 +488,5 @@ class NS(hildon.Program):
 
 
 if __name__ == "__main__":  
-    app = NS() 
+    app = StopwatchApp() 
     app.run()         
